# Japanese Kana-Latin Transliteration Tables
[![PyPI](https://img.shields.io/pypi/v/jtran.svg)](https://pypi.python.org/pypi/jtran)
[![Build Status](https://travis-ci.com/kateabr/jtran.svg?token=2iwzrCfZDArjbexpKxss&branch=master)](https://travis-ci.com/kateabr/jtran)


## Install

```
pip install jtran
```
